@@ -166,7 +166,7 @@ class RDSClient():
             query = f"SELECT tagged FROM neuralplatform_document WHERE id = {document_id};"
             if self.select_query(query, fetchone=True)['tagged']:
                 query = f"SELECT classDefinition_id FROM neuralplatform_classification WHERE document_id = {document_id};"
-                class_id = self.select_query(query, fetchone=True)['class_id']
+                class_id = self.select_query(query, fetchone=True)['classDefinition_id']
                 query = f"SELECT * FROM neuralplatform_page WHERE document_id = {document_id};"
                 pages = self.select_query(query)
                 for page in pages:
